@@ -59,13 +59,17 @@ class NexusConnector(object):
         self.parent = parent
         self.parentName = self.parent.nodeName
         self.nodeId = None #str(uuid.uuid4())
-        self.protocol = "wss" 
+        # self.protocol = "wss" 
         self.token = token
         self.axon = axonURL
+
+        if not '://' in self.axon:
+            raise NoProtocolException(self.axon)
+
         self.debug = debug
 
 
-        self.wsConf = self.protocol + "://"+ str(self.axon)
+        # self.wsConf = self.protocol + "://"+ str(self.axon)
 
         self.logger = logger
 
@@ -142,7 +146,7 @@ class NexusConnector(object):
         """
         self.debug = mode
 
-    def listen(self, **kwargs): # TODO: is it possible to use kwargs twice? - for init() and connect()?
+    def listen(self, blocking = True, **kwargs): # TODO: is it possible to use kwargs twice? - for init() and connect()?
         """Start listening on Websocket communication"""
         # SSLOPTS
         ssl_verify = not "DISABLE_SSL_VERIFY" in os.environ
@@ -153,8 +157,11 @@ class NexusConnector(object):
         while(_reconnect):
             _reconnect = self.reconnect # Do While
             try:
-                self.sio.connect(self.wsConf)
-                self.sio.wait()
+                self.sio.connect(self.axon)
+                if blocking:
+                    self.sio.wait()
+                else:
+                    break #this will never be reached if wait() is used
             except socketio.exceptions.ConnectionError as e:
                 if self.reconnect:
                     self.logger.error(str(e) + " - make sure you are connected to the Internet and the Axon on {} is running".format(self.axon.split('/')[0]))
@@ -333,9 +340,9 @@ class NexusConnector(object):
         self.isConnected = False
         self.isRegistered = False
         self.logger.log(self.parent.NEXUSINFO, "Connection closed")
-        self.parent.onDisconnected()
+        self.parent._onDisconnected()
         if self.reconnect:
-            self.parent.setUp()
+            self.parent._setUp()
 
     def defineCallbacks(self):
         @self.sio.event
