@@ -13,7 +13,9 @@ class ExampleHook(Hook):
     '''
     Hook for testing
     '''
-    pass
+    def onConnected(self):
+        super(ExampleHook, self).onConnected()
+        self.disconnect() # disconnects after successfully connecting
 
 class TestHook(unittest.TestCase):
     '''Tests for the Hook'''
@@ -22,9 +24,8 @@ class TestHook(unittest.TestCase):
         '''
         test to initialize a Hook
         '''
-        # h = ExampleHook()
-        pass # TODO: For this a pong / testing instance (which is always available) is needed + .btnexusrc
-
-
-if __name__ == '__main__':
-    unittest.main()
\ No newline at end of file
+        print('TESTING THE HOOK')
+        h = ExampleHook(reconnection=False)
+        
+if __name__ == "__main__":
+    unittest.main()
